@@ -13,7 +13,6 @@
 
 #include "cmCTest.h"
 #include "cmSystemTools.h"
-#include "cmXMLSafe.h"
 
 #include <cmsys/RegularExpression.hxx>
 #include <cmsys/ios/sstream>
@@ -324,7 +323,7 @@ private:
 //----------------------------------------------------------------------------
 void cmCTestP4::SetP4Options(std::vector<char const*> &CommandOptions)
 {
-  if(P4Options.size() == 0)
+  if(P4Options.empty())
     {
     const char* p4 = this->CommandLineTool.c_str();
     P4Options.push_back(p4);
@@ -346,14 +345,10 @@ void cmCTestP4::SetP4Options(std::vector<char const*> &CommandOptions)
     //The CTEST_P4_OPTIONS variable adds additional Perforce command line
     //options before the main command
     std::string opts = this->CTest->GetCTestConfiguration("P4Options");
-    std::vector<cmStdString> args =
+    std::vector<std::string> args =
             cmSystemTools::ParseArguments(opts.c_str());
 
-    for(std::vector<cmStdString>::const_iterator ai = args.begin();
-        ai != args.end(); ++ai)
-      {
-      P4Options.push_back(ai->c_str());
-      }
+    P4Options.insert(P4Options.end(), args.begin(), args.end());
     }
 
   CommandOptions.clear();
@@ -451,7 +446,7 @@ void cmCTestP4::LoadRevisions()
   ChangeLists.clear();
   this->RunChild(&p4_changes[0], &out, &err);
 
-  if(ChangeLists.size() == 0)
+  if(ChangeLists.empty())
       return;
 
   //p4 describe -s ...@1111111,2222222
@@ -538,8 +533,8 @@ bool cmCTestP4::UpdateImpl()
     {
     opts = this->CTest->GetCTestConfiguration("P4UpdateOptions");
     }
-  std::vector<cmStdString> args = cmSystemTools::ParseArguments(opts.c_str());
-  for(std::vector<cmStdString>::const_iterator ai = args.begin();
+  std::vector<std::string> args = cmSystemTools::ParseArguments(opts.c_str());
+  for(std::vector<std::string>::const_iterator ai = args.begin();
       ai != args.end(); ++ai)
     {
     p4_sync.push_back(ai->c_str());
