@@ -20,7 +20,6 @@ bool cmMessageCommand
     this->SetError("called with incorrect number of arguments");
     return false;
     }
-  std::string message;
   std::vector<std::string>::const_iterator i = args.begin();
 
   cmake::MessageType type = cmake::MESSAGE;
@@ -52,15 +51,29 @@ bool cmMessageCommand
     status = true;
     ++i;
     }
-
-  for(;i != args.end(); ++i)
+  else if (*i == "DEPRECATION")
     {
-    message += *i;
+    if (this->Makefile->IsOn("CMAKE_ERROR_DEPRECATED"))
+      {
+      fatal = true;
+      type = cmake::DEPRECATION_ERROR;
+      }
+    else if (this->Makefile->IsOn("CMAKE_WARN_DEPRECATED"))
+      {
+      type = cmake::DEPRECATION_WARNING;
+      }
+    else
+      {
+      return true;
+      }
+    ++i;
     }
 
+  std::string message = cmJoin(cmRange(i, args.end()), std::string());
+
   if (type != cmake::MESSAGE)
     {
-    this->Makefile->IssueMessage(type, message.c_str());
+    this->Makefile->IssueMessage(type, message);
     }
   else
     {
